@@ -27,6 +27,7 @@ if __name__ == "__main__":
 #    management.call_command("test", "reversion_compare.PersonPetModelTest", verbosity=2, traceback=True, interactive=False)
     sys.exit()
 
+from django.core.urlresolvers import reverse
 from django.db.models.loading import get_models, get_app
 from django.test import TestCase
 from django.contrib.auth.models import User
@@ -50,10 +51,11 @@ from reversion.models import Revision, Version
 from reversion_compare import helpers
 
 from reversion_compare_test_project.reversion_compare_test_app.models import SimpleModel, Person, Pet, \
-    Factory, Car, VariantModel
+    Factory, Car, VariantModel, CustomModel
 
 # Needs to import admin module to register all models via CompareVersionAdmin/VersionAdmin
 import reversion_compare_test_project.reversion_compare_test_app.admin
+from reversion_compare_test_project.reversion_compare_test_app.admin import custom_revision_manager
 
 
 class TestData(object):
@@ -221,6 +223,16 @@ class TestData(object):
             print "version 1:", item
 
         return item
+        
+    def create_CustomModel_data(self):
+        with reversion.create_revision():
+            item1 = CustomModel.objects.create(text="version one")
+
+        if self.verbose:
+            print "version 1:", item1
+
+        return item1
+
 
 class BaseTestCase(TestCase):
     def setUp(self):
@@ -274,7 +286,9 @@ class EnvironmentTest(BaseTestCase):
     def test_model_registering(self):
         test_app = get_app(app_label="reversion_compare_test_app")
         models = get_models(app_mod=test_app, include_auto_created=False, include_deferred=False, only_installed=True)
-        self.assertEqual(len(reversion.get_registered_models()), len(models))
+        default_registered = len(reversion.get_registered_models())
+        custom_registered = len(custom_revision_manager.get_registered_models())
+        self.assertEqual(default_registered + custom_registered, len(models))
 
 
 class SimpleModelTest(BaseTestCase):
@@ -648,4 +662,59 @@ last line"""
 <ins>+nisi ut aliquip ex ea commodo consequat. Duis added aute irure dolor in reprehenderit in voluptate velit</ins>
 """)
         self.assertNotContains(response, "first line")
-        self.assertNotContains(response, "last line")
\ No newline at end of file
+        self.assertNotContains(response, "last line")
+        
+        
+class CustomModelTest(BaseTestCase):
+    "Test a model which uses a custom reversion manager."
+    
+    def setUp(self):
+        super(CustomModelTest, self).setUp()
+        test_data = TestData(verbose=False)
+        self.item = test_data.create_CustomModel_data()
+        
+    def test_initial_state(self):
+        "Test initial data creation and model registration."
+        self.assertTrue(custom_revision_manager.is_registered(CustomModel))
+        self.assertEqual(CustomModel.objects.count(), 1)
+        self.assertEqual(custom_revision_manager.get_for_object(self.item).count(), 1)
+        self.assertEqual(Revision.objects.all().count(), 1)
+        
+    def test_text_diff(self):
+        "Generate a new revision and check for a correctly generated diff."
+        with reversion.create_revision():
+            self.item.text = "version two"
+            self.item.save()
+        queryset = custom_revision_manager.get_for_object(self.item)
+        version_ids = queryset.values_list("pk", flat=True)
+        self.assertEqual(len(version_ids), 2)
+        url_name = 'admin:%s_%s_compare' % (CustomModel._meta.app_label, CustomModel._meta.module_name)
+        diff_url = reverse(url_name, args=(self.item.pk, ))
+        data = {"version_id2": version_ids[0], "version_id1": version_ids[1]}
+        response = self.client.get(diff_url, data=data)
+        self.assertContains(response, "<del>- version one</del>")
+        self.assertContains(response, "<ins>+ version two</ins>")
+        
+    def test_version_selection(self):
+        "Generate two revisions and view the version history selection."
+        with reversion.create_revision():
+            self.item.text = "version two"
+            self.item.save()
+        with reversion.create_revision():
+            self.item.text = "version three"
+            self.item.save()
+        queryset = custom_revision_manager.get_for_object(self.item)
+        version_ids = queryset.values_list("pk", flat=True)
+        self.assertEqual(len(version_ids), 3)
+        url_name = 'admin:%s_%s_history' % (CustomModel._meta.app_label, CustomModel._meta.module_name)
+        history_url = reverse(url_name, args=(self.item.pk, ))
+        response = self.client.get(history_url)
+        self.assertContainsHtml(response,
+            '<input type="submit" value="compare">',
+            '<input type="radio" name="version_id1" value="%i" style="visibility:hidden" />' % version_ids[0],
+            '<input type="radio" name="version_id2" value="%i" checked="checked" />' % version_ids[0],
+            '<input type="radio" name="version_id1" value="%i" checked="checked" />' % version_ids[1],
+            '<input type="radio" name="version_id2" value="%i" />' % version_ids[1],
+            '<input type="radio" name="version_id1" value="%i" />' % version_ids[2],
+            '<input type="radio" name="version_id2" value="%i" />' % version_ids[2],
+        )
\ No newline at end of file
